==> ec2-0.19.0-sources.jar: software/amazon/awscdk/services/ec2/cloudformation/VPCEndpointResource.java <==
package software.amazon.awscdk.services.ec2.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpoint.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.11 (build 44c3b9b)", date = "2018-12-04T12:19:22.602Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.cloudformation.VPCEndpointResource")
public class VPCEndpointResource extends software.amazon.awscdk.Resource {
    protected VPCEndpointResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ec2.cloudformation.VPCEndpointResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::EC2::VPCEndpoint``.
     * @param parent the ``cdk.Construct`` this ``VPCEndpointResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``VPCEndpointResource``
     */
    public VPCEndpointResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.cloudformation.VPCEndpointResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.ec2.cloudformation.VPCEndpointResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.ec2.cloudformation.VPCEndpointResourceProps.class);
    }

    /**
     * @cloudformation_attribute CreationTimestamp
     */
    public java.lang.String getVpcEndpointCreationTimestamp() {
        return this.jsiiGet("vpcEndpointCreationTimestamp", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute DnsEntries
     */
    public software.amazon.awscdk.services.ec2.VPCEndpointDnsEntries getVpcEndpointDnsEntries() {
        return this.jsiiGet("vpcEndpointDnsEntries", software.amazon.awscdk.services.ec2.VPCEndpointDnsEntries.class);
    }

    public java.lang.String getVpcEndpointId() {
        return this.jsiiGet("vpcEndpointId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute NetworkInterfaceIds
     */
    public software.amazon.awscdk.services.ec2.VPCEndpointNetworkInterfaceIds getVpcEndpointNetworkInterfaceIds() {
        return this.jsiiGet("vpcEndpointNetworkInterfaceIds", software.amazon.awscdk.services.ec2.VPCEndpointNetworkInterfaceIds.class);
    }
}

==> ec2-0.21.0-sources.jar: software/amazon/awscdk/services/ec2/cloudformation/VPCEndpointResource.java <==
package software.amazon.awscdk.services.ec2.cloudformation;

/**
 * @deprecated "cloudformation.VPCEndpointResource" will be deprecated in a future release in favor of "CfnVPCEndpoint" (see https://github.com/awslabs/aws-cdk/issues/878)
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpoint.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-20T13:30:41.996Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.cloudformation.VPCEndpointResource")
public class VPCEndpointResource extends software.amazon.awscdk.Resource {
    protected VPCEndpointResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ec2.cloudformation.VPCEndpointResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::EC2::VPCEndpoint``.
     * @param parent the ``cdk.Construct`` this ``VPCEndpointResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``VPCEndpointResource``
     */
    public VPCEndpointResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.cloudformation.VPCEndpointResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.ec2.cloudformation.VPCEndpointResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.ec2.cloudformation.VPCEndpointResourceProps.class);
    }

    /**
     * @cloudformation_attribute CreationTimestamp
     */
    public java.lang.String getVpcEndpointCreationTimestamp() {
        return this.jsiiGet("vpcEndpointCreationTimestamp", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute DnsEntries
     */
    public software.amazon.awscdk.services.ec2.VPCEndpointDnsEntries getVpcEndpointDnsEntries() {
        return this.jsiiGet("vpcEndpointDnsEntries", software.amazon.awscdk.services.ec2.VPCEndpointDnsEntries.class);
    }

    public java.lang.String getVpcEndpointId() {
        return this.jsiiGet("vpcEndpointId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute NetworkInterfaceIds
     */
    public software.amazon.awscdk.services.ec2.VPCEndpointNetworkInterfaceIds getVpcEndpointNetworkInterfaceIds() {
        return this.jsiiGet("vpcEndpointNetworkInterfaceIds", software.amazon.awscdk.services.ec2.VPCEndpointNetworkInterfaceIds.class);
    }
}
